@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: authenticate
 version: 1.3.3
-id: authenticate-1.3.3-8786f6078b464d3c3f52185ef882a223
-key: authe_BfeIAf2U83c0QOtY4UwBay
+id: authenticate-1.3.3-c7cd7dbf777a77b23e23ff23b790e7d4
+key: authe_1u6B4wfvlys1vgKxkMqKtG
 license: BSD3
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -23,7 +23,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/authenticate-1.3.3
 library-dirs: /usr/lib/ghc-7.10.3/site-local/authenticate-1.3.3
 data-dir: /usr/share/arm-linux-ghc-7.10.3/authenticate-1.3.3
-hs-libraries: HSauthenticate-1.3.3-BfeIAf2U83c0QOtY4UwBay
+hs-libraries: HSauthenticate-1.3.3-1u6B4wfvlys1vgKxkMqKtG
 depends:
     aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
     attoparsec-0.13.0.1-522c252ad233781393fab28c8daf023a
@@ -38,11 +38,11 @@ depends:
     monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
     network-uri-2.6.1.0-0e39aca8530572505c01ef548c540bd6
     resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
-    tagstream-conduit-0.5.5.3-450e403db691bac03a51e13c7201c073
+    tagstream-conduit-0.5.5.3-c659b13637e6399e888788db23405b6c
     text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
-    xml-conduit-1.3.4-233ad2c214e14cf140bab4070afaa144
+    xml-conduit-1.3.4-2cb0835929c2dc7743cd241414dfd06a
 haddock-interfaces: /usr/share/doc/haskell-authenticate/html/authenticate.haddock
 haddock-html: /usr/share/doc/haskell-authenticate/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
